django-permissions-auditor
==========================

![Build](https://github.com/AACEngineering/django-permissions-auditor/workflows/Test/badge.svg)
[![codecov](https://codecov.io/gh/AACEngineering/django-permissions-auditor/branch/master/graph/badge.svg)](https://codecov.io/gh/AACEngineering/django-permissions-auditor)
[![](https://img.shields.io/pypi/v/django-permissions-auditor.svg)](https://pypi.org/project/django-permissions-auditor/)
[![](https://readthedocs.org/projects/django-permissions-auditor/badge/?version=latest&style=flat)](https://django-permissions-auditor.readthedocs.io/en/latest/)


https://django-permissions-auditor.readthedocs.io/en/latest/


Admin site for auditing and managing permissions for views in your Django app.


![Screenshot](docs/img/admin_views.png?raw=true "Screenshot")


Automatically parse Django views in your project and pull out the permissions required to view them. Easily extensible to work with custom permission schemes.


![Screenshot](docs/img/admin_permissions.png?raw=true "Screenshot")
